# airflow-common-operators

Common Operators / Tasks for [Apache Airflow](https://airflow.apache.org)

[![Build Status](https://github.com/timkpaine/airflow-common-operators/actions/workflows/build.yml/badge.svg)](https://github.com/timkpaine/airflow-common-operators/actions?query=workflow%3A%22Build+Status%22)
[![codecov](https://codecov.io/gh/timkpaine/airflow-common-operators/branch/main/graph/badge.svg)](https://codecov.io/gh/timkpaine/airflow-common-operators)
[![License](https://img.shields.io/github/license/timkpaine/airflow-common-operators)](https://github.com/timkpaine/airflow-common-operators)
[![PyPI](https://img.shields.io/pypi/v/airflow-common-operators.svg)](https://pypi.python.org/pypi/airflow-common-operators)
